"use strict";
/*
* This program and the accompanying materials are made available under the terms of the *
* Eclipse Public License v2.0 which accompanies this distribution, and is available at *
* https://www.eclipse.org/legal/epl-v20.html                                      *
*                                                                                 *
* SPDX-License-Identifier: EPL-2.0                                                *
*                                                                                 *
* Copyright Contributors to the Zowe Project.                                     *
*                                                                                 *
*/
Object.defineProperty(exports, "__esModule", { value: true });
const child_process_1 = require("child_process");
const path = require("path");
const vscode = require("vscode");
const nls = require("vscode-nls");
const localize = nls.config({ messageFormat: nls.MessageFormat.file })(__filename);
/**
 * Load all profiles by spawning a script that uses the users' globally installed
 * 'node' command. This should work regardless of what credential manager plugins
 * the user has installed
 */
function loadAllProfiles() {
    const getProfileProcess = child_process_1.spawnSync("node", [path.join(__dirname, "getAllProfiles.js")]);
    if (getProfileProcess.status !== 0) {
        throw new Error(localize(0, null) +
            getProfileProcess.stderr.toString());
    }
    if (getProfileProcess.stdout.toString().length === 0) {
        throw new Error(localize(1, null) +
            localize(2, null)
            + getProfileProcess.stderr.toString());
    }
    return JSON.parse(getProfileProcess.stdout.toString());
}
exports.loadAllProfiles = loadAllProfiles;
/**
 * Load the default zosmf profile
 */
function loadDefaultProfile(log) {
    const getProfileProcess = child_process_1.spawnSync("node", [path.join(__dirname, "getDefaultProfile.js")]);
    if (getProfileProcess.status !== 0) {
        throw new Error(localize(3, null) +
            getProfileProcess.stderr.toString());
    }
    if (getProfileProcess.stdout.toString().length === 0) {
        const defaultProfileMessage = localize(4, null)
            + localize(5, null)
            + localize(6, null)
            + localize(7, null)
            + localize(8, null);
        // Display info message to user
        vscode.window.showInformationMessage(defaultProfileMessage);
        // Include stack trace in debug log
        log.debug(defaultProfileMessage + localize(9, null) + getProfileProcess.stderr.toString());
        // Keep from continuing
        return undefined;
    }
    return JSON.parse(getProfileProcess.stdout.toString());
}
exports.loadDefaultProfile = loadDefaultProfile;

//# sourceMappingURL=ProfileLoader.js.map
